@@ -47,7 +47,7 @@
       DATA      CPARAS(23)/'LXLOG3  '/, LX(23) / .FALSE. /
       DATA      CPARAS(24)/'LYLOG3  '/, LX(24) / .FALSE. /
       DATA      CPARAS(25)/'LZLOG3  '/, LX(25) / .FALSE. /
-      DATA      CPARAS(26)/'MARKFONT'/, LX(26) / .TRUE. /
+      DATA      CPARAS(26)/'LMRKFNT '/, LX(26) / .TRUE. /
 
 *     / LONG  NAME /
 
