@@ -1,7 +1,8 @@
 *-----------------------------------------------------------------------
 *     USPACK AUTO SCALING ROUTINE (LOG)                DCL 5.0 95/09/04
 *-----------------------------------------------------------------------
-
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
+*-----------------------------------------------------------------------
       SUBROUTINE USUSCL(CAXIS, UMIN,  UMAX,  VMIN,  VMAX)
 
       REAL        SC(4)
@@ -29,8 +30,8 @@
 
       CALL GNSAVE
       CALL GNSBLK(SC, 4)
-      CALL GNGE(UMAX, BUMAX, IPMAX)
-      CALL GNLE(UMIN, BUMIN, IPMIN)
+      CALL GNGE(MAX(UMAX,UMIN), BUMAX, IPMAX)
+      CALL GNLE(MIN(UMIN,UMAX), BUMIN, IPMIN)
       CALL GNRSET
 
       IF(IPMAX.LE.IPMIN+1) THEN
@@ -55,7 +56,7 @@
 
 *--------------------------- NLBL & NTISCKS ----------------------------
 
-      DV = (VMAX-VMIN) / (LOG10(UMAX)-LOG10(UMIN)) / CW
+      DV = (VMAX-VMIN) / ABS(LOG10(UMAX)-LOG10(UMIN)) / CW
       IF(DV.GE.10.) THEN
         NLBL   = 3
         NTICKS = 9
